@@ -98,12 +98,12 @@ int main(int argc, char **argv)
     QAction* openAction = shortCutActions.action(QStringLiteral("_launch"));
     KGlobalAccel::self()->setDefaultShortcut(openAction, {Qt::Key_Print});
     QAction* fullScreenAction = shortCutActions.action(QStringLiteral("FullScreenScreenShot"));
-    KGlobalAccel::self()->setDefaultShortcut(fullScreenAction, {Qt::SHIFT + Qt::Key_Print});
-    QAction* currentScreenAction = shortCutActions.action(QStringLiteral("CurrentMonitorScreenShot"));
+    KGlobalAccel::self()->setDefaultShortcut(fullScreenAction, {Qt::SHIFT | Qt::Key_Print});
+    //QAction* currentScreenAction = shortCutActions.action(QStringLiteral("CurrentMonitorScreenShot"));
     QAction* activeWindowAction = shortCutActions.action(QStringLiteral("ActiveWindowScreenShot"));
-    KGlobalAccel::self()->setDefaultShortcut(activeWindowAction, {Qt::META + Qt::Key_Print});
+    KGlobalAccel::self()->setDefaultShortcut(activeWindowAction, {Qt::META | Qt::Key_Print});
     QAction* regionAction = shortCutActions.action(QStringLiteral("RectangularRegionScreenShot"));
-    KGlobalAccel::self()->setDefaultShortcut(regionAction, {Qt::META + Qt::SHIFT + Qt::Key_Print});
+    KGlobalAccel::self()->setDefaultShortcut(regionAction, {Qt::META | Qt::SHIFT | Qt::Key_Print});
     // Finally reinstate the old shortcuts
     if (found_spectacle) {
         KGlobalAccel::self()->setShortcut(openAction, launchKey, KGlobalAccel::NoAutoloading);
