@@ -1,21 +1,8 @@
 /*
- *  Copyright 2019 David Redondo <kde@david-redondo.de>
- *  Copyright (C) 2015 Boudhayan Gupta <bgupta@kde.org>
+ *  SPDX-FileCopyrightText: 2019 David Redondo <kde@david-redondo.de>
+ *  SPDX-FileCopyrightText: 2015 Boudhayan Gupta <bgupta@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU Lesser General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU Lesser General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "KSWidget.h"
@@ -63,22 +50,30 @@ KSWidget::KSWidget(Platform::GrabModes theGrabModes, QWidget *parent)
     // the capture mode options first
     mCaptureModeLabel = new QLabel(i18n("<b>Capture Mode</b>"), this);
     mCaptureArea = new QComboBox(this);
-    QString lFullScreenLabel = QApplication::screens().count() == 1
-            ? i18n("Full Screen")
-            : i18n("Full Screen (All Monitors)");
 
     if (theGrabModes.testFlag(Platform::GrabMode::AllScreens)) {
+
+        QString lFullScreenLabel = QApplication::screens().count() == 1
+                ? i18n("Full Screen")
+                : i18n("Full Screen (All Monitors)");
+
         mCaptureArea->insertItem(0, lFullScreenLabel, Spectacle::CaptureMode::AllScreens);
-        mCaptureArea->insertItem(1, i18n("Rectangular Region"), Spectacle::CaptureMode::RectangularRegion);
+    }
+    if (theGrabModes.testFlag(Platform::GrabMode::AllScreensScaled) &&  QApplication::screens().count() > 1) {
+        QString lFullScreenLabel = i18n("Full Screen (All Monitors, scaled)");
+        mCaptureArea->insertItem(1, lFullScreenLabel, Spectacle::CaptureMode::AllScreensScaled);
+    }
+    if (theGrabModes.testFlag(Platform::GrabMode::PerScreenImageNative)) {
+        mCaptureArea->insertItem(2, i18n("Rectangular Region"), Spectacle::CaptureMode::RectangularRegion);
     }
     if (theGrabModes.testFlag(Platform::GrabMode::CurrentScreen)) {
-        mCaptureArea->insertItem(2, i18n("Current Screen"), Spectacle::CaptureMode::CurrentScreen);
+        mCaptureArea->insertItem(3, i18n("Current Screen"), Spectacle::CaptureMode::CurrentScreen);
     }
     if (theGrabModes.testFlag(Platform::GrabMode::ActiveWindow)) {
-        mCaptureArea->insertItem(3, i18n("Active Window"), Spectacle::CaptureMode::ActiveWindow);
+        mCaptureArea->insertItem(4, i18n("Active Window"), Spectacle::CaptureMode::ActiveWindow);
     }
     if (theGrabModes.testFlag(Platform::GrabMode::WindowUnderCursor)) {
-        mCaptureArea->insertItem(4, i18n("Window Under Cursor"), Spectacle::CaptureMode::WindowUnderCursor);
+        mCaptureArea->insertItem(5, i18n("Window Under Cursor"), Spectacle::CaptureMode::WindowUnderCursor);
     }
     if (theGrabModes.testFlag(Platform::GrabMode::TransientWithParent)) {
         mTransientWithParentAvailable = true;
@@ -226,7 +221,7 @@ void KSWidget::lockOnClickEnabled()
 void KSWidget::lockOnClickDisabled()
 {
     mCaptureOnClick->setCheckState(Qt::Unchecked);
-    mCaptureOnClick->setEnabled(false);
+    mCaptureOnClick->hide();
     mDelayMsec->setEnabled(true);
 }
 
@@ -271,6 +266,7 @@ void KSWidget::captureModeChanged(int theIndex)
         mCaptureTransientOnly->setEnabled(false);
         break;
     case Spectacle::CaptureMode::AllScreens:
+    case Spectacle::CaptureMode::AllScreensScaled:
     case Spectacle::CaptureMode::CurrentScreen:
     case Spectacle::CaptureMode::RectangularRegion:
         mWindowDecorations->setEnabled(false);
@@ -308,7 +304,9 @@ void KSWidget::setProgress(double progress)
 void KSWidget::showAnnotator()
 {
     mStack->setCurrentIndex(1);
-    mAnnotator->loadImage(ExportManager::instance()->pixmap());
+    QPixmap px = ExportManager::instance()->pixmap();
+    px.setDevicePixelRatio(qApp->devicePixelRatio());
+    mAnnotator->loadImage(px);
 }
 
 void KSWidget::hideAnnotator()
