@@ -1,21 +1,8 @@
 /*
- *  Copyright 2019 David Redondo <kde@david-redondo.de>
- *  Copyright (C) 2015 Boudhayan Gupta <bgupta@kde.org>
+ *  SPDX-FileCopyrightText: 2019 David Redondo <kde@david-redondo.de>
+ *  SPDX-FileCopyrightText: 2015 Boudhayan Gupta <bgupta@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU Lesser General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU Lesser General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "SettingsDialog.h"
@@ -28,8 +15,6 @@
 #include <KLocalizedString>
 #include <KShortcutWidget>
 
-#include <QIcon>
-#include <QMessageBox>
 
 SettingsDialog::SettingsDialog(QWidget *parent) :
     KConfigDialog(parent, QStringLiteral("settings"), Settings::self())
