@@ -1,21 +1,6 @@
 /* This file is part of Spectacle, the KDE screenshot utility
- * Copyright (C) 2016 Martin Graesslin <mgraesslin@kde.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- *
+ * SPDX-FileCopyrightText: 2016 Martin Graesslin <mgraesslin@kde.org>
+
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
@@ -37,33 +22,45 @@
 
 /* -- Static Helpers --------------------------------------------------------------------------- */
 
-static int readData(int theFile, QByteArray &theDataOut)
+static bool readData(int fd, QByteArray &data)
 {
-    // implementation based on QtWayland file qwaylanddataoffer.cpp
-    char    lBuffer[4096];
-    int     lRetryCount = 0;
-    ssize_t lBytesRead = 0;
+    fd_set readset;
+    FD_ZERO(&readset);
+    FD_SET(fd, &readset);
+    struct timeval timeout;
+    timeout.tv_sec = 30;
+    timeout.tv_usec = 0;
+    char buf[4096 * 16];
+
     while (true) {
-        lBytesRead = QT_READ(theFile, lBuffer, sizeof lBuffer);
-        // give user 30 sec to click a window, afterwards considered as error
-        if (lBytesRead == -1 && (errno == EAGAIN) && ++lRetryCount < 30000) {
-            usleep(1000);
+        int ready = select(FD_SETSIZE, &readset, nullptr, nullptr, &timeout);
+        if (ready < 0) {
+            qWarning() << "PlatformKWinWayland readData: select() failed" << strerror(errno);
+            return false;
+        } else if (ready == 0) {
+            qWarning("PlatformKWinWayland readData: timeout reading from pipe");
+            return false;
         } else {
-            break;
+            int n = read(fd, buf, sizeof buf);
+
+            if (n < 0) {
+                qWarning() << "PlatformKWinWayland readData: read() failed" << strerror(errno);
+                return false;
+            } else if (n == 0) {
+                return true;
+            } else {
+                data.append(buf, n);
+            }
         }
     }
 
-    if (lBytesRead > 0) {
-        theDataOut.append(lBuffer, lBytesRead);
-        lBytesRead = readData(theFile, theDataOut);
-    }
-    return lBytesRead;
+    Q_UNREACHABLE();
 }
 
 static QImage readImage(int thePipeFd)
 {
     QByteArray lContent;
-    if (readData(thePipeFd, lContent) != 0) {
+    if (!readData(thePipeFd, lContent)) {
         close(thePipeFd);
         return QImage();
     }
@@ -78,7 +75,7 @@ static QImage readImage(int thePipeFd)
 static QVector<QImage> readImages(int thePipeFd)
 {
     QByteArray lContent;
-    if (readData(thePipeFd, lContent) != 0) {
+    if (!readData(thePipeFd, lContent)) {
         close(thePipeFd);
         return QVector<QImage>();
     }
